@@ -86,10 +86,10 @@ def get_passphrase_from_cmd(passphrase_cmd: str) -> str:
 
 
 @exception_to_message(UserError, logger)
-def get_passphrase_from_cmd_or_prompt(passphrase_cmd: Optional[str]) -> str:
+def get_passphrase_from_cmd_or_prompt(msg: str, passphrase_cmd: Optional[str]) -> str:
     if passphrase_cmd:
         return get_passphrase_from_cmd(passphrase_cmd)
-    return getpass("Please enter your gpg private key password:")
+    return getpass(msg)
 
 
 @exception_to_message(UserError, logger)
@@ -111,7 +111,9 @@ def encrypt(
             "--verify_dtr is not possible when offline is " "enabled in the config"
         )
     if config.sign_encrypted_data and not dry_run:
-        kwargs["passphrase"] = get_passphrase_from_cmd_or_prompt(passphrase_cmd)
+        kwargs["passphrase"] = get_passphrase_from_cmd_or_prompt(
+            "Please enter your gpg private key password:", passphrase_cmd
+        )
     else:
         kwargs["passphrase"] = None
     return workflows_encrypt(
@@ -130,7 +132,9 @@ def decrypt(*args, dry_run: bool, passphrase_cmd: Optional[str], **kwargs):
     if dry_run:
         kwargs["passphrase"] = None
     else:
-        kwargs["passphrase"] = get_passphrase_from_cmd_or_prompt(passphrase_cmd)
+        kwargs["passphrase"] = get_passphrase_from_cmd_or_prompt(
+            "Please enter your gpg private key password:", passphrase_cmd
+        )
     return workflows_decrypt(*args, dry_run=dry_run, **kwargs)
 
 
@@ -140,6 +144,7 @@ def transfer(
     *,
     connection: str = None,
     two_factor_callback,
+    passphrase_cmd: Optional[str] = None,
     config: Config,
     protocol=None,
     protocol_args: Dict[str, Any] = None,
@@ -163,9 +168,15 @@ def transfer(
             "or 'connection' "
             "has to be given as an argument"
         )
+    for pw_arg in protocol.required_password_args(**protocol_args):
+        if protocol_args.get(pw_arg) is None:
+            protocol_args[pw_arg] = get_passphrase_from_cmd_or_prompt(
+                f"Please enter the password for the argument `{pw_arg}`:",
+                passphrase_cmd,
+            )
     return workflows_transfer(
         files,
-        protocol=protocol,
+        protocol=protocol.upload,
         protocol_args=protocol_args,
         config=config,
         two_factor_callback=two_factor_callback,
@@ -277,6 +288,7 @@ class Cli(Subcommands):
                     "protocol args can be overwritten by the "
                     "protocol_args option"
                 ),
+                "passphrase_cmd": dict(help=passphrase_override["help"]),
                 "dry_run": dry_run_override,
                 "verify_dtr": verify_dtr_override,
             },
