@@ -7,6 +7,7 @@ from pathlib import Path
 from contextlib import contextmanager
 from itertools import filterfalse
 from typing import List, Iterable, IO, Sequence, Union
+
 try:
     from typing import TypedDict
 except ImportError:
@@ -36,9 +37,11 @@ def check_tar(tar: str) -> None:
     :raises UserError:
     """
     if not tar.endswith(".tar"):
-        raise UserError(f"Input file '{tar}' does not have .tar extension.\n"
-                        "Only .tar files can be used as input of the data "
-                        "decryption command.")
+        raise UserError(
+            f"Input file '{tar}' does not have .tar extension.\n"
+            "Only .tar files can be used as input of the data "
+            "decryption command."
+        )
     check_tar_contents(os.path.realpath(tar))
 
 
@@ -50,14 +53,15 @@ def check_tar_contents(path: str) -> None:
     """
     with tarfile.open(path, format=tarfile.PAX_FORMAT) as tar:
         content = set(tar.getnames())
-        content.add(METADATA_FILE_SIG)  # NOTE: Backward compatibility to v0.9
         if content != PACKAGE_CONTENT:
             raise UserError(
-                f"Input file '{path}' has non-compliant content:\n" +
-                "\n".join(content) + "\n\n"
+                f"Input file '{path}' has non-compliant content:\n"
+                + "\n".join(content)
+                + "\n\n"
                 "BioMedIT input tar files must contain exactly the following "
                 "files:\n"
                 f"\t- {METADATA_FILE} file with metadata\n"
+                f"\t- {METADATA_FILE_SIG} file with a detached signature of the metadata\n"
                 f"\t- {DATA_FILE_ENCRYPTED} file with the encrypted data"
             )
 
@@ -74,6 +78,7 @@ class ArchiveFileBase(ABC):
 
 class ArchiveInMemoryFile(ArchiveFileBase):
     """An ArchiveFileBase whose content_container is a bytes instance."""
+
     def add_to_tar(self, tar: tarfile.TarFile):
         t = tarfile.TarInfo(self.archive_path)
         t.size = len(self.content_container)
@@ -83,18 +88,21 @@ class ArchiveInMemoryFile(ArchiveFileBase):
 
 class ArchiveFile(ArchiveFileBase):
     """An ArchiveFileBase whose content_container is a file like object."""
+
     def add_to_tar(self, tar: tarfile.TarFile):
-        t = tar.gettarinfo(name=self.content_container.name,
-                           arcname=self.archive_path,
-                           fileobj=None)
+        t = tar.gettarinfo(
+            name=self.content_container.name, arcname=self.archive_path, fileobj=None
+        )
         with self.content_container as f_opened:
             tar.addfile(t, f_opened)
 
 
-def write_tar(content: Sequence[ArchiveFileBase],
-              output: Union[str, IO[bytes]],
-              compress_level: int = 6,
-              compress_algo: str = 'gz') -> None:
+def write_tar(
+    content: Sequence[ArchiveFileBase],
+    output: Union[str, IO[bytes]],
+    compress_level: int = 6,
+    compress_algo: str = "gz",
+) -> None:
     """Create a ".tar" or ".tar.gz" archive from files on disk or from a
     data stream, i.e. in-memory files.
 
@@ -122,16 +130,26 @@ def write_tar(content: Sequence[ArchiveFileBase],
     # i.e. file vs fileobject.
     # Note that currently the "w|gz" mode do not support the "compresslevel"
     # argument, so we use "w:gz" instead.
-    tarfile_arguments: TarfileArguments = {'mode': f'w:{compress_algo}' if
-        compress_level > 0 else 'w' if isinstance(output, str) else 'w|'}
+    tarfile_arguments: TarfileArguments = {
+        "mode": f"w:{compress_algo}"
+        if compress_level > 0
+        else "w"
+        if isinstance(output, str)
+        else "w|"
+    }
     if isinstance(output, str):
-        tarfile_arguments['name'] = output
+        tarfile_arguments["name"] = output
     else:
-        tarfile_arguments['fileobj'] = output
-    tarfile_arguments['mode'] = f'w:{compress_algo}' if compress_level > 0 \
-        else 'w' if isinstance(output, str) else 'w|'
+        tarfile_arguments["fileobj"] = output
+    tarfile_arguments["mode"] = (
+        f"w:{compress_algo}"
+        if compress_level > 0
+        else "w"
+        if isinstance(output, str)
+        else "w|"
+    )
     if compress_level > 0:
-        tarfile_arguments['compresslevel'] = compress_level
+        tarfile_arguments["compresslevel"] = compress_level
 
     # Compress input files into tarball.
     with tarfile.open(**tarfile_arguments) as tar:
@@ -141,22 +159,23 @@ def write_tar(content: Sequence[ArchiveFileBase],
     if isinstance(output, str):
         # Verify the tarball file was created correctly. If not, delete it.
         if not Path(output).is_file():
-            raise UserError(f'compression failed for [{output}]: '
-                            f'tarball not created.')
-        with tarfile.open(output, 'r') as tar:
-            missing_files = {Path(p) for p in archive_file_names} - \
-                            {Path(p) for p in tar.getnames()}
+            raise UserError(
+                f"compression failed for [{output}]: " f"tarball not created."
+            )
+        with tarfile.open(output, "r") as tar:
+            missing_files = {Path(p) for p in archive_file_names} - {
+                Path(p) for p in tar.getnames()
+            }
         if missing_files:
             delete_files(output)
-            raise UserError(f'compression failed for [{output}]: '
-                            f'one or more files are missing in tarball.')
+            raise UserError(
+                f"compression failed for [{output}]: "
+                f"one or more files are missing in tarball."
+            )
 
 
 def is_relative(path: str):
-    return not (
-        os.path.isabs(path) or
-        os.path.normpath(path).startswith("..")
-    )
+    return not (os.path.isabs(path) or os.path.normpath(path).startswith(".."))
 
 
 def assert_relative(files: Iterable[str]):
@@ -165,16 +184,15 @@ def assert_relative(files: Iterable[str]):
     if non_relative:
         raise UserError(
             "The archive contains files with absolute path or paths ending "
-            "in a parent directory:\n" +
-            "\n".join(non_relative))
+            "in a parent directory:\n" + "\n".join(non_relative)
+        )
 
 
 def check_extracted(paths: Iterable[str]):
     """Tests if all paths in :paths: exist now on the file system"""
     failed = tuple(filterfalse(os.path.exists, paths))
     if failed:
-        raise UserError("Failed to extract to following files: \n" +
-                        "\n".join(failed))
+        raise UserError("Failed to extract to following files: \n" + "\n".join(failed))
 
 
 @contextmanager
@@ -197,8 +215,10 @@ def extract_with_progress(archive: IO[bytes], progress: ProgressInterface, *file
                 member = tar.extractfile(files[0])
                 yield with_progress(member, progress) if member else None
             else:
-                yield (tar.extractfile(file_name) for
-                       file_name in progress_iter(files, progress))
+                yield (
+                    tar.extractfile(file_name)
+                    for file_name in progress_iter(files, progress)
+                )
         # 'tarfile.getmember' ('extractfile' invokes it): If 'file_name' can
         # not be found in the archive, 'KeyError' is raised.
         except KeyError as e:
@@ -219,8 +239,9 @@ def extract(archive: IO[bytes], *files):
                 raise UserError(f"In archive {archive.name}: {e.args[0]}") from e
 
 
-def unpack_from_stream(archive: IO[bytes], dest: str, content: List[str],
-                       mode: str = 'r|*'):
+def unpack_from_stream(
+    archive: IO[bytes], dest: str, content: List[str], mode: str = "r|*"
+):
     """Extract all files in the tarball from a stream.
     After unpacking the function checks that all files have been properly
     extracted by comparing the new files on disk to the list of files present
