@@ -3,14 +3,14 @@
 
 import sys
 import logging
-from PySide2.QtWidgets import QApplication
 
 from . import main_window
+from .pyside import QtWidgets
 from ..utils.log import add_rotating_file_handler_to_logger
 
 
 def run():
-    application = QApplication(sys.argv)
+    application = QtWidgets.QApplication(sys.argv)
     window = main_window.MainWindow()
     logger = logging.getLogger()
     add_rotating_file_handler_to_logger(
