@@ -1,31 +1,29 @@
 from functools import partial
 from pathlib import Path
-from typing import Callable, Optional
+from typing import Callable, Optional, Tuple
 
-from PySide2 import QtCore, QtWidgets
-from PySide2.QtCore import QItemSelectionModel
-from PySide2.QtWidgets import QPushButton, QLabel, QCheckBox, QWidget
+from .pyside import QtCore, QtWidgets
 
 from .model import AppData
 from .parallel import Worker
 from ..utils.progress import ProgressInterface
 
 
-class MandatoryLabel(QLabel):
+class MandatoryLabel(QtWidgets.QLabel):
     """A label extension which appends a '*' to label's end to mark the field as required."""
 
     def __init__(self, label: str):
         super().__init__(label + " <sup><font color='red'>*</font></sup>")
 
 
-class SelectionButton(QPushButton):
+class SelectionButton(QtWidgets.QPushButton):
     """A push button extension which connects this button to given selection model.
 
     The button is disabled by default. And gets enabled when the selection has, at least,
     one selected row.
     """
 
-    def __init__(self, label: str, selection_model: QItemSelectionModel):
+    def __init__(self, label: str, selection_model: QtCore.QItemSelectionModel):
         super().__init__(label)
         self.setEnabled(False)
         self._selection_model = selection_model
@@ -35,9 +33,6 @@ class SelectionButton(QPushButton):
         # Following works better than using 'QItemSelection', especially in cases
         # where multiple selection is possible
         self.setEnabled(bool(len(self._selection_model.selectedRows())))
-        # Repaint the button on each selection changed. Should happen automatically,
-        # but does NOT seem to be always the case on Mac OS X.
-        self.repaint()
 
 
 class GuiProgress(QtCore.QObject, ProgressInterface):
@@ -69,7 +64,6 @@ class ConsoleWidget(QtWidgets.QGroupBox):
 
     def clear(self) -> None:
         self.textbox.clear()
-        self.textbox.repaint()
 
     def append(self, text: str) -> None:
         self.textbox.appendPlainText(text)
@@ -96,8 +90,6 @@ class PathInput:
         self.path = path
         self.text.setText("" if path is None else str(path))
         self.text.editingFinished.emit()
-        # 'repaint' invocation is needed on MacOS X
-        self.text.repaint()
 
     def _update_location(self, directory: bool):
         if self.path and self.path.exists():
@@ -148,16 +140,14 @@ class TabMixin:
         self.progress_bar = QtWidgets.QProgressBar(self)
 
     @staticmethod
-    def _create_disabled_button(action_name: str) -> QPushButton:
+    def _create_disabled_button(action_name: str) -> QtWidgets.QPushButton:
         button = QtWidgets.QPushButton(action_name)
         button.setEnabled(False)
         return button
 
     def set_buttons_enabled(self, enabled: bool):
         self.btn_run.setEnabled(enabled)
-        self.btn_run.repaint()
         self.btn_test.setEnabled(enabled)
-        self.btn_test.repaint()
 
     def create_run_panel(self, panel_name: str, action: Callable, action_name: str):
         self.run_panel = QtWidgets.QGroupBox(panel_name)
@@ -193,9 +183,17 @@ def run_dialog(parent, msg: str, password: bool = True):
     return dialog_pwd.textValue()
 
 
+def show_warning(title: str, text: str, parent: Optional[QtWidgets.QWidget] = None):
+    msg = QtWidgets.QMessageBox(parent=parent)
+    msg.setWindowTitle(title)
+    msg.setIcon(QtWidgets.QMessageBox.Warning)
+    msg.setText(text)
+    msg.show()
+
+
 def create_verify_dtr_checkbox(
-    app_data: AppData, field_name: str, parent: Optional[QWidget] = None
-) -> QCheckBox:
+    app_data: AppData, field_name: str, parent: Optional[QtWidgets.QWidget] = None
+) -> QtWidgets.QCheckBox:
     verify_dtr = QtWidgets.QCheckBox("Verify DTR ID", parent)
     verify_dtr.setStatusTip("Verify DTR (Data Transfer Request) ID")
     verify_dtr.setChecked(not app_data.config.offline and app_data.encrypt_verify_dtr)
@@ -240,3 +238,34 @@ class FieldMapping:
                 ) from None
         for key in set(self._mapping.keys()) - set(parameters.keys()):
             self._mapping[key](None)
+
+
+def create_slider(
+    minimum: int,
+    maximum: int,
+    initial_value: int,
+    status_tip: Optional[str],
+    on_change: Optional[Callable[[int], None]] = None,
+    show_ticks: bool = False,
+    interval: int = 1,
+) -> Tuple[QtWidgets.QSlider, QtWidgets.QLabel]:
+    widget_value = QtWidgets.QLabel(str(initial_value))
+
+    slider = QtWidgets.QSlider(QtCore.Qt.Horizontal)
+    slider.setMinimum(minimum)
+    slider.setMaximum(maximum)
+    slider.setValue(initial_value)
+    slider.setTickInterval(interval)
+    if status_tip is not None:
+        slider.setStatusTip(status_tip)
+    if show_ticks:
+        slider.setTickPosition(QtWidgets.QSlider.TicksBelow)
+
+    def update_text(value: int):
+        widget_value.setText(str(value))
+
+    slider.valueChanged.connect(update_text)
+    if on_change is not None:
+        slider.valueChanged.connect(on_change)
+
+    return slider, widget_value
