@@ -1,10 +1,9 @@
 from functools import partial
 
-from PySide2 import QtWidgets, QtCore
-
 from .component import TabMixin, PathInput, GuiProgress, run_dialog
 from .file_selection_widget import ArchiveOnlyFileSelectionWidget
 from .parallel import Worker
+from .pyside import QtCore, QtWidgets
 from ..workflows import decrypt
 
 
@@ -33,7 +32,9 @@ class DecryptTab(QtWidgets.QWidget, TabMixin):
         self.set_buttons_enabled(len(self.app_data.decrypt_files) > 0)
 
     def create_files_panel(self):
-        box = ArchiveOnlyFileSelectionWidget("Files to decrypt", self)
+        box = ArchiveOnlyFileSelectionWidget(
+            "Files to decrypt (hint: you can drag & drop files)", self
+        )
         box.file_list_model.layoutChanged.connect(
             lambda: setattr(self.app_data, "decrypt_files", box.get_list())
         )
