@@ -1,13 +1,11 @@
 from datetime import datetime
 from functools import partial
 
-from PySide2 import QtWidgets, QtCore, QtGui
-from PySide2.QtWidgets import QHeaderView, QLabel
-
 from .component import (
     TabMixin,
     PathInput,
     GuiProgress,
+    create_slider,
     run_dialog,
     SelectionButton,
     MandatoryLabel,
@@ -16,6 +14,8 @@ from .component import (
 from .file_selection_widget import DirectoryAndFileSelectionWidget
 from .model import TableModel
 from .parallel import Worker
+from .pyside import QtCore, QtGui, QtWidgets
+from .settings_tab import LABEL_COMPRESSION_LEVEL, STATUS_TIP_COMPRESSION_LEVEL
 from ..core.metadata import Purpose
 from ..workflows import encrypt
 
@@ -51,7 +51,8 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
 
     def create_files_panel(self):
         box = DirectoryAndFileSelectionWidget(
-            "Files and/or directories to encrypt", self
+            "Files and/or directories to encrypt (hint: you can drag & drop files)",
+            self,
         )
         box.file_list_model.layoutChanged.connect(
             lambda: setattr(self.app_data, "encrypt_files", box.get_list())
@@ -73,7 +74,7 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         recipients_output_view.setModel(recipients_output_model)
         recipients_output_view.verticalHeader().hide()
         recipients_output_view.horizontalHeader().setSectionResizeMode(
-            QHeaderView.ResizeToContents
+            QtWidgets.QHeaderView.ResizeToContents
         )
         recipients_output_view.horizontalHeader().setStretchLastSection(True)
         recipients_output_view.setSelectionBehavior(QtWidgets.QTableView.SelectRows)
@@ -122,7 +123,11 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
 
         layout = QtWidgets.QGridLayout(group_box)
         layout.addWidget(
-            QLabel("Select data sender and add at least one recipient"), 0, 0, 1, 3
+            QtWidgets.QLabel("Select data sender and add at least one recipient"),
+            0,
+            0,
+            1,
+            3,
         )
         layout.addWidget(MandatoryLabel("Sender"), 1, 0, 1, 1)
         layout.addWidget(sender_widget, 1, 1, 1, 1)
@@ -141,29 +146,23 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         grid_layout.addWidget(self._create_metadata_group_box(), 0, 1, 1, 1)
         grid_layout.addWidget(self._create_output_group_box(), 1, 1, 1, 1)
         # Add spacer
-        grid_layout.addWidget(QLabel(), 2, 1, 1, 1)
+        grid_layout.addWidget(QtWidgets.QLabel(), 2, 1, 1, 1)
         return grid_layout
 
     def _create_output_group_box(self):
         group_box = QtWidgets.QGroupBox("Output", self)
         group_box.setLayout(QtWidgets.QGridLayout(group_box))
         # Create fields
-        compress = QtWidgets.QCheckBox("Compress input data", group_box)
-        compress.setStatusTip("Compress input data files before encryption")
-        compress.setChecked(self.app_data.encrypt_compress)
         output_suffix = QtWidgets.QLineEdit(group_box)
         output_suffix.setStatusTip(
             "(optional) File name suffix in the " "format datetime_suffix.tar"
         )
-        output_suffix.setValidator(QtGui.QRegExpValidator(QtCore.QRegExp(r"[\w-]*")))
+        output_suffix.setValidator(
+            QtGui.QRegularExpressionValidator(QtCore.QRegularExpression(r"[\w-]*"))
+        )
         output_location = PathInput(path=self.app_data.encrypt_output_location)
         output_location.status_tip = "Destination folder for the encrypted package"
         # Add actions
-        compress.stateChanged.connect(
-            lambda state: setattr(
-                self.app_data, "encrypt_compress", state == QtCore.Qt.Checked
-            )
-        )
         output_suffix.editingFinished.connect(
             lambda: setattr(
                 self.app_data, "encrypt_output_suffix", output_suffix.text()
@@ -173,12 +172,23 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
             partial(setattr, self.app_data, "encrypt_output_location")
         )
 
-        group_box.layout().addWidget(QLabel("Suffix"), 0, 0, 1, 1)
+        slider_widgets = create_slider(
+            minimum=0,
+            maximum=9,
+            initial_value=self.app_data.encrypt_compression_level,
+            status_tip=STATUS_TIP_COMPRESSION_LEVEL,
+            on_change=lambda n: setattr(self.app_data, "encrypt_compression_level", n),
+        )
+        compression_layout = QtWidgets.QHBoxLayout()
+        for w in (QtWidgets.QLabel(LABEL_COMPRESSION_LEVEL),) + slider_widgets:
+            compression_layout.addWidget(w)
+
+        group_box.layout().addWidget(QtWidgets.QLabel("Suffix"), 0, 0, 1, 1)
         group_box.layout().addWidget(output_suffix, 0, 1, 1, 1)
-        group_box.layout().addWidget(QLabel("Location"), 1, 0, 1, 1)
+        group_box.layout().addWidget(QtWidgets.QLabel("Location"), 1, 0, 1, 1)
         group_box.layout().addWidget(output_location.text, 1, 1, 1, 1)
         group_box.layout().addWidget(output_location.btn, 2, 1, 1, 1)
-        group_box.layout().addWidget(compress, 3, 0, 1, 2)
+        group_box.layout().addLayout(compression_layout, 3, 0, 1, 2)
         return group_box
 
     def _create_metadata_group_box(self):
@@ -193,7 +203,7 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         )
         purpose = QtWidgets.QComboBox(group_box)
         purpose.setStatusTip("(optional) Purpose of the package")
-        purpose.addItems(("",) + tuple(Purpose.__members__.keys()))
+        purpose.addItems(("",) + tuple(x.name for x in Purpose))
         purpose.setCurrentText("")
 
         # Add actions
@@ -206,10 +216,10 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
                 self.app_data, "encrypt_purpose", None if text == "" else Purpose(text)
             )
         )
-        group_box.layout().addWidget(QLabel("DTR ID"), 0, 0, 1, 1)
+        group_box.layout().addWidget(QtWidgets.QLabel("DTR ID"), 0, 0, 1, 1)
         group_box.layout().addWidget(transfer_id, 0, 1, 1, 1)
         group_box.layout().addWidget(verify_dtr, 1, 0, 1, 2)
-        group_box.layout().addWidget(QLabel("Purpose"), 2, 0, 1, 1)
+        group_box.layout().addWidget(QtWidgets.QLabel("Purpose"), 2, 0, 1, 1)
         group_box.layout().addWidget(purpose, 2, 1, 1, 1)
         return group_box
 
@@ -247,7 +257,7 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
             output_name=output_path,
             dry_run=dry_run,
             offline=self.app_data.config.offline,
-            compression_level=None if self.app_data.encrypt_compress else 0,
+            compression_level=self.app_data.encrypt_compression_level,
             purpose=self.app_data.encrypt_purpose,
             progress=progress,
             on_error=lambda _: None,
