@@ -1,10 +1,9 @@
 from pathlib import Path
 from typing import Iterable, List
 
-from PySide2 import QtWidgets, QtCore
-from PySide2.QtWidgets import QAbstractButton
-
-from sett.gui.component import SelectionButton, MandatoryLabel
+from sett import APP_NAME_SHORT
+from .pyside import QtWidgets, QtCore, QtGui
+from .component import SelectionButton, MandatoryLabel, show_warning
 
 
 class FileSelectionWidget(QtWidgets.QGroupBox):
@@ -31,24 +30,35 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
         for i, btn in enumerate(buttons):
             layout.addWidget(btn, i + 1, 2)
         self.setLayout(layout)
+        self.setAcceptDrops(True)
+
+    # pylint: disable=no-self-use
+    def dragEnterEvent(self, event: QtGui.QDragEnterEvent) -> None:
+        if event.mimeData().hasUrls():
+            event.accept()
+        else:
+            event.ignore()
+
+    def dropEvent(self, event: QtGui.QDropEvent) -> None:
+        self._update_paths(url.toLocalFile() for url in event.mimeData().urls())
 
     def get_list(self) -> List[str]:
         """Returns the paths."""
         return self.file_list_model.stringList()
 
-    def _create_buttons(self) -> List[QAbstractButton]:
+    def _create_buttons(self) -> List[QtWidgets.QAbstractButton]:
         return [
             self._create_add_files_button(),
             self._create_remove_selected_button(),
             self._create_clear_list_button(),
         ]
 
-    def _create_add_files_button(self) -> QAbstractButton:
+    def _create_add_files_button(self) -> QtWidgets.QAbstractButton:
         button = QtWidgets.QPushButton("Add files", self)
         button.clicked.connect(self._add_files)
         return button
 
-    def _create_remove_selected_button(self) -> QAbstractButton:
+    def _create_remove_selected_button(self) -> QtWidgets.QAbstractButton:
         def clear_selected() -> None:
             indices = self.file_list_view.selectedIndexes()
             for index in indices:
@@ -61,7 +71,7 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
         button.clicked.connect(clear_selected)
         return button
 
-    def _create_clear_list_button(self) -> QAbstractButton:
+    def _create_clear_list_button(self) -> QtWidgets.QAbstractButton:
         def clear_list() -> None:
             # Clear the selection BEFORE resetting the model
             self.file_list_view.selectionModel().clearSelection()
@@ -120,3 +130,18 @@ class ArchiveOnlyFileSelectionWidget(FileSelectionWidget):
 
     def __init__(self, label_text, parent):
         super().__init__(label_text, parent, "Archives *.tar (*.tar)")
+
+    def dropEvent(self, event: QtGui.QDropEvent) -> None:
+        paths = [
+            url.toLocalFile()
+            for url in event.mimeData().urls()
+            if url.toLocalFile().endswith(".tar")
+        ]
+        if paths:
+            self._update_paths(paths)
+        else:
+            show_warning(
+                APP_NAME_SHORT,
+                "Failed to load files. Only '.tar' archives are allowed.",
+                self,
+            )
