@@ -1,12 +1,13 @@
 import html
 from pathlib import Path
-
-from PySide2 import QtWidgets, QtCore, QtGui
+from typing import Optional, Sequence
 
 from sett.core.error import UserError
 from .component import SelectionButton
 from .parallel import Worker
+from .pyside import QtCore, QtGui, QtWidgets
 from ..core import crypt
+from ..utils.config import Config
 from ..workflows import (
     upload_keys as upload_keys_workflow,
     request_sigs as request_sigs_workflow,
@@ -156,7 +157,7 @@ class KeysTab(QtWidgets.QWidget):
         btn_sign = offline_btn(
             "Request signature", "Request signature for the selected keys"
         )
-        btn_sign.clicked.connect(self.request_signature)
+        btn_sign.clicked.connect(self.send_signature_request)
         btn_delete = SelectionButton("Delete keys", selection_model)
         btn_delete.setStatusTip("Delete selected keys from your computer")
         btn_delete.clicked.connect(self.delete_keys)
@@ -331,42 +332,12 @@ class KeysTab(QtWidgets.QWidget):
                 )
                 self.threadpool.start(worker)
 
-    def request_signature(self):
-        msg = QtWidgets.QMessageBox()
-        msg.setWindowTitle("Key signing request")
-        msg.setText("Do you want to request signature for the selected key?")
-        msg.setIcon(QtWidgets.QMessageBox.Question)
-        msg.setStandardButtons(QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel)
-        msg_ok = QtWidgets.QMessageBox()
-        msg_ok.setIcon(QtWidgets.QMessageBox.Information)
-        msg_ok.setWindowTitle("Key signing request")
-        msg_ok.setText("Key signing request has been sent.")
-        msg_warn = QtWidgets.QMessageBox()
-        msg_warn.setWindowTitle("Key signing request")
-        msg_warn.setIcon(QtWidgets.QMessageBox.Warning)
-
+    def send_signature_request(self):
         selected_keys = [
             index.model().get_value(index)
             for index in self.pub_keys_view.selectedIndexes()
         ]
-        for key in selected_keys:
-            msg.setDetailedText(self.key_to_text(key))
-            if key is selected_keys[0]:
-                click_show_details(msgbox=msg)
-            status = msg.exec_()
-            if status == QtWidgets.QMessageBox.Ok:
-                worker = Worker(
-                    request_sigs_workflow.request_sigs,
-                    key_ids=[key.key_id],
-                    config=self.app_data.config,
-                    logger=(request_sigs_workflow.logger,),
-                    on_error=raise_,
-                )
-                worker.signals.result.connect(lambda x: msg_ok.exec_())
-                worker.signals.error.connect(
-                    lambda x: (msg_warn.setText(format(x[1])), msg_warn.exec_())
-                )
-                self.threadpool.start(worker)
+        request_signature(selected_keys, self.app_data.config, self.threadpool, self)
 
     def _update_display(self, index: QtCore.QModelIndex):
         style = (
@@ -469,8 +440,8 @@ class KeyGenDialog(QtWidgets.QDialog):
         self.text_pass_repeat = QtWidgets.QLineEdit()
         self.toggle_password_visibility(False)
 
-        re_email = QtCore.QRegExp(r"[^@]+@[^@]+\.[^@]+")
-        self.text_email.setValidator(QtGui.QRegExpValidator(re_email))
+        re_email = QtCore.QRegularExpression(r"[^@]+@[^@]+\.[^@]+")
+        self.text_email.setValidator(QtGui.QRegularExpressionValidator(re_email))
 
         self.btn_run = QtWidgets.QPushButton("Generate key")
         self.btn_run.setDefault(True)
@@ -479,7 +450,7 @@ class KeyGenDialog(QtWidgets.QDialog):
         btn_cancel.clicked.connect(self.close)
         btn_show_pass = QtWidgets.QPushButton("Show")
         btn_show_pass.setCheckable(True)
-        btn_show_pass.clicked[bool].connect(self.toggle_password_visibility)
+        btn_show_pass.clicked.connect(self.toggle_password_visibility)
 
         layout = QtWidgets.QGridLayout()
         layout.addWidget(QtWidgets.QLabel("Full name"), 0, 0)
@@ -513,7 +484,7 @@ class KeyGenDialog(QtWidgets.QDialog):
         self.text_pass_repeat.clear()
 
     def post_key_creation(self, key: Key):
-        msg = QtWidgets.QMessageBox()
+        msg = QtWidgets.QMessageBox(self)
         msg.setWindowTitle("GPG Key Generation")
         msg.setIcon(QtWidgets.QMessageBox.Information)
         try:
@@ -546,6 +517,13 @@ class KeyGenDialog(QtWidgets.QDialog):
             )
         finally:
             msg.exec_()
+            if (
+                self.parent().app_data.config.key_validation_authority_keyid
+                and not self.parent().app_data.config.offline
+            ):
+                request_signature(
+                    (key,), self.parent().app_data.config, self.threadpool, self
+                )
             self.clear_form()
             self.parent().update_private_keys()
             self.parent().update_public_keys()
@@ -577,3 +555,44 @@ def click_show_details(msgbox: QtWidgets.QMessageBox):
     for button in msgbox.buttons():
         if msgbox.buttonRole(button) is QtWidgets.QMessageBox.ButtonRole.ActionRole:
             button.click()
+
+
+def request_signature(
+    keys: Sequence[Key],
+    config: Config,
+    threadpool: QtCore.QThreadPool,
+    parent: Optional[QtWidgets.QWidget] = None,
+):
+    msg = QtWidgets.QMessageBox(parent)
+    msg.setWindowTitle("Key signing request")
+    msg.setText("Do you want to request signature for this key?")
+    msg.setIcon(QtWidgets.QMessageBox.Question)
+    msg.setStandardButtons(QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
+    msg_ok = QtWidgets.QMessageBox(parent)
+    msg_ok.setIcon(QtWidgets.QMessageBox.Information)
+    msg_ok.setWindowTitle("Key signing request")
+    msg_ok.setText("Key signing request has been sent.")
+    msg_warn = QtWidgets.QMessageBox(parent)
+    msg_warn.setWindowTitle("Key signing request")
+    msg_warn.setIcon(QtWidgets.QMessageBox.Warning)
+
+    def show_warning(e):
+        msg_warn.setText(format(e[1]))
+        msg_warn.exec_()
+
+    for key in keys:
+        msg.setDetailedText(KeysTab.key_to_text(key))
+        if key is keys[0]:
+            click_show_details(msgbox=msg)
+        status = msg.exec_()
+        if status == QtWidgets.QMessageBox.Yes:
+            worker = Worker(
+                request_sigs_workflow.request_sigs,
+                key_ids=[key.key_id],
+                config=config,
+                logger=(request_sigs_workflow.logger,),
+                on_error=raise_,
+            )
+            worker.signals.result.connect(lambda _: msg_ok.exec_())
+            worker.signals.error.connect(show_warning)
+            threadpool.start(worker)
