@@ -1,9 +1,5 @@
 import warnings
 
-from PySide2 import QtWidgets, QtGui, QtCore
-from PySide2.QtCore import QSysInfo
-from PySide2.QtGui import QKeySequence
-
 from sett import (
     APP_NAME_LONG,
     URL_READTHEDOCS,
@@ -13,6 +9,7 @@ from sett import (
     URL_GITLAB,
     VERSION_WITH_DEPS,
 )
+from .component import show_warning
 from .settings_tab import SettingsTab, config_to_settings
 from ..core.versioncheck import check_version
 from .keys_tab import KeysTab
@@ -21,6 +18,7 @@ from .decrypt_tab import DecryptTab
 from .encrypt_tab import EncryptTab
 from .model import AppData
 from .parallel import Worker
+from .pyside import QtCore, QtGui, QtWidgets, QAction
 from ..utils.config import load_config, save_config, config_to_dict
 
 QtCore.QThreadPool.globalInstance().setExpiryTimeout(-1)
@@ -41,9 +39,10 @@ class MainWindow(QtWidgets.QMainWindow):
         with warnings.catch_warnings(record=True) as w:
             config = load_config()
             if w:
-                self.show_warning(
+                show_warning(
                     "Configuration Error",
                     "\n".join(format(warning.message) for warning in w),
+                    self,
                 )
         return config
 
@@ -68,26 +67,26 @@ class MainWindow(QtWidgets.QMainWindow):
         self.setStatusBar(self.status)
 
     def add_menu(self):
-        action_exit = QtWidgets.QAction(QtGui.QIcon(), "&Exit", self)
-        action_exit.setShortcut(QKeySequence("Ctrl+Q"))
+        action_exit = QAction(QtGui.QIcon(), "&Exit", self)
+        action_exit.setShortcut(QtGui.QKeySequence("Ctrl+Q"))
         action_exit.setStatusTip("Exit application")
         action_exit.triggered.connect(self.close)
 
         menu = self.menuBar()
-        menu.setNativeMenuBar(QSysInfo.productType() != "osx")
+        menu.setNativeMenuBar(QtCore.QSysInfo.productType() != "macos")
         menu_file = menu.addMenu("&File")
         menu_file.addAction(action_exit)
 
-        action_help = QtWidgets.QAction(QtGui.QIcon(), "&Documentation", self)
+        action_help = QAction(QtGui.QIcon(), "&Documentation", self)
         action_help.setStatusTip("Open online documentation")
-        action_help.setShortcut(QKeySequence(QKeySequence.HelpContents))
+        action_help.setShortcut(QtGui.QKeySequence(QtGui.QKeySequence.HelpContents))
         action_help.triggered.connect(open_url(URL_READTHEDOCS))
 
-        action_bug_report = QtWidgets.QAction(QtGui.QIcon(), "&Report an Issue", self)
+        action_bug_report = QAction(QtGui.QIcon(), "&Report an Issue", self)
         action_bug_report.setStatusTip("Open online bug report form")
         action_bug_report.triggered.connect(open_url(URL_GITLAB_ISSUES))
 
-        action_about = QtWidgets.QAction(QtGui.QIcon(), "&About", self)
+        action_about = QAction(QtGui.QIcon(), "&About", self)
         action_about.setStatusTip("Show info about application")
         action_about.triggered.connect(self.show_about)
 
@@ -134,7 +133,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 return "\n".join(format(warning.message) for warning in w)
 
         worker = Worker(get_warnings)
-        worker.signals.result.connect(lambda x: x and self.show_warning(self.title, x))
+        worker.signals.result.connect(lambda x: x and show_warning(self.title, x, self))
         QtCore.QThreadPool.globalInstance().start(worker)
 
     def show_about(self):
@@ -157,13 +156,6 @@ class MainWindow(QtWidgets.QMainWindow):
         )
         msg.show()
 
-    def show_warning(self, title: str, text: str):
-        msg = QtWidgets.QMessageBox(parent=self)
-        msg.setWindowTitle(title)
-        msg.setIcon(QtWidgets.QMessageBox.Warning)
-        msg.setText(text)
-        msg.show()
-
 
 def open_url(url: str):
     """Returns a function that will opens the specified URL in the user's
