@@ -14,8 +14,7 @@ from typing import (
     Callable,
 )
 
-from PySide2 import QtCore
-
+from .pyside import QtCore
 from ..core.metadata import Purpose
 from ..utils.config import Config
 
@@ -120,7 +119,7 @@ class AppData:
     encrypt_recipients: Tuple[str, ...] = ()
     encrypt_transfer_id: Optional[str] = None
     encrypt_purpose: Optional[Purpose] = None
-    encrypt_compress: bool = True
+    encrypt_compression_level: int = 6
     encrypt_output_suffix: str = ""
     encrypt_output_location: Path = field(default_factory=Path.home)
     encrypt_files: List[str] = field(default_factory=list)
@@ -156,3 +155,5 @@ class AppData:
         if self.config.output_dir:
             self.encrypt_output_location = Path(self.config.output_dir)
             self.decrypt_output_location = Path(self.config.output_dir)
+        if self.config.compression_level is not None:
+            self.encrypt_compression_level = self.config.compression_level
