@@ -3,7 +3,7 @@ import sys
 import traceback
 from typing import Collection
 
-from PySide2.QtCore import Signal, QObject, QRunnable
+from .pyside import QtCore
 
 
 class LoggerHandler(logging.Handler):
@@ -16,16 +16,16 @@ class LoggerHandler(logging.Handler):
             self.callback(self.format(record))
 
 
-class WorkerSignals(QObject):
-    started = Signal()
-    finished = Signal()
-    error = Signal(tuple)
-    result = Signal(object)
-    progress = Signal(int)
-    logging = Signal(str)
+class WorkerSignals(QtCore.QObject):
+    started = QtCore.Signal()
+    finished = QtCore.Signal()
+    error = QtCore.Signal(tuple)
+    result = QtCore.Signal(object)
+    progress = QtCore.Signal(int)
+    logging = QtCore.Signal(str)
 
 
-class Worker(QRunnable):
+class Worker(QtCore.QRunnable):
     """Worker can run an arbitrary function in a separate thread.
 
     :param fn: function to run in a thread
