@@ -4,7 +4,6 @@ from functools import partial
 from typing import Optional, Sequence
 
 import time
-from PySide2 import QtWidgets, QtCore, QtGui
 
 from .component import (
     TabMixin,
@@ -17,6 +16,7 @@ from .component import (
 )
 from .file_selection_widget import ArchiveOnlyFileSelectionWidget
 from .parallel import Worker
+from .pyside import QtCore, QtGui, QtWidgets
 from .. import protocols
 from ..core.error import UserError
 from ..utils.config import Connection, ConnectionStore
@@ -52,7 +52,9 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
         self.set_buttons_enabled(len(self.app_data.transfer_files) > 0)
 
     def create_files_panel(self):
-        box = ArchiveOnlyFileSelectionWidget("Encrypted files to transfer", self)
+        box = ArchiveOnlyFileSelectionWidget(
+            "Encrypted files to transfer (hint: you can drag & drop files)", self
+        )
         box.file_list_model.layoutChanged.connect(
             lambda: setattr(self.app_data, "transfer_files", box.get_list())
         )
@@ -379,7 +381,9 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
             transfer.transfer,
             files=self.app_data.transfer_files,
             logger=(transfer.logger, protocols.sftp.logger),
-            protocol=protocols.protocols_by_name[self.app_data.transfer_protocol_name],
+            protocol=protocols.protocols_by_name[
+                self.app_data.transfer_protocol_name
+            ].upload,
             protocol_args=self.app_data.transfer_protocol_args[
                 self.app_data.transfer_protocol_name
             ],
@@ -405,7 +409,9 @@ class ConnectionDialog(QtWidgets.QDialog):
     ):
         super().__init__(parent=parent)
         self.setWindowTitle("Connection profile")
-        self.setWindowFlags(self.windowFlags() & ~QtCore.Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(
+            self.windowFlags() & ~QtCore.Qt.WindowContextHelpButtonHint  # type: ignore
+        )
 
         btn_box = QtWidgets.QDialogButtonBox(
             QtWidgets.QDialogButtonBox.Ok | QtWidgets.QDialogButtonBox.Cancel
@@ -415,7 +421,7 @@ class ConnectionDialog(QtWidgets.QDialog):
 
         self.text_field = QtWidgets.QLineEdit()
         self.text_field.setValidator(
-            QtGui.QRegExpValidator(QtCore.QRegExp(r"[\w\-@]+"))
+            QtGui.QRegularExpressionValidator(QtCore.QRegularExpression(r"[\w\-@]+"))
         )
         self.text_field.setText(default_input)
 
