@@ -7,9 +7,7 @@ from ..core.error import UserError
 # TODO: change type to a tuple of items implementing a protocol
 # (once protocol is standard in python)
 protocols = (liquid_files, sftp)
-protocols_by_name = {
-    p.__name__.replace(__name__ + ".", ""): p.upload for p in protocols  # type: ignore
-}
+protocols_by_name = {p.__name__.replace(__name__ + ".", ""): p for p in protocols}
 
 __all__ = tuple(protocols_by_name)
 
