@@ -1,6 +1,6 @@
 import os
 import json
-from typing import List, Iterable, Tuple
+from typing import Iterable, Tuple, Sequence
 from datetime import date
 from datetime import timedelta
 import urllib.parse
@@ -17,9 +17,13 @@ from ..core.error import UserError
 from ..core.request import build_opener
 
 
+def required_password_args(**_) -> Sequence:
+    return ()
+
+
 def upload(
-    files: List[str],
-    recipients: List[str],
+    files: Sequence[str],
+    recipients: Sequence[str],
     host: str,
     api_key: str,
     subject: str = "BiomedIT file transfer",
