@@ -22,10 +22,12 @@ class LogTask:
         errors.
     """
 
-    def __init__(self,
-                 message: str,
-                 ok_logger: Callable = logging.info,
-                 err_logger: Callable = logging.error):
+    def __init__(
+        self,
+        message: str,
+        ok_logger: Callable = logging.info,
+        err_logger: Callable = logging.error,
+    ):
         self.ok_logger = ok_logger
         self.err_logger = err_logger
         self.message = message
@@ -49,6 +51,7 @@ def exception_to_message(error_types: ExceptionType = (), logger=logging):
     in or equal to error_types, occurring while executing the decorated
     function, logging an error and exiting python.
     """
+
     def dec(f):
         @wraps(f)
         def wrapped_f(*args, on_error=lambda _: sys.exit(1), **kwargs):
@@ -62,7 +65,9 @@ def exception_to_message(error_types: ExceptionType = (), logger=logging):
             except error_types as e:
                 logger.error(format(e))
                 on_error(e)
+
         return wrapped_f
+
     return dec
 
 
@@ -71,9 +76,7 @@ class LoggerExt(logging.Logger):
 
     def log_task(self, message: str) -> LogTask:
         """A context manager to log a task which can potentially fail"""
-        return LogTask(message,
-                       ok_logger=self.info,
-                       err_logger=self.error)
+        return LogTask(message, ok_logger=self.info, err_logger=self.error)
 
 
 logging.setLoggerClass(LoggerExt)
@@ -93,11 +96,13 @@ def create_logger(name, logger_level: int = logging.DEBUG) -> LoggerExt:
     return cast(LoggerExt, logger)  # We called logging.setLoggerClass
 
 
-def add_rotating_file_handler_to_logger(logger: logging.Logger,
-                                        log_dir: str,
-                                        logger_level: int = logging.DEBUG,
-                                        file_max_number: int = 1000,
-                                        file_max_size: int = 1000000) -> None:
+def add_rotating_file_handler_to_logger(
+    logger: logging.Logger,
+    log_dir: str,
+    logger_level: int = logging.DEBUG,
+    file_max_number: int = 1000,
+    file_max_size: int = 1000000,
+) -> None:
     """Add a rotating file handler to the specified logger. When the logfile
     reaches file_max_size, it gets renamed (a number is appended) and a new
     logfile is started. When file_max_number is exceeded, the oldest backup
@@ -116,25 +121,27 @@ def add_rotating_file_handler_to_logger(logger: logging.Logger,
         try:
             log_dir_path.mkdir(parents=True)
         except PermissionError:
-            logger.error(
-                f'unable to create directory {log_dir_path.as_posix()}.')
+            logger.error(f"unable to create directory {log_dir_path.as_posix()}.")
 
     # Setup handler for logging info to file. The file logging format adds
     # the data and time at the start of each logged message.
-    log_file = log_dir_path.joinpath('log')
+    log_file = log_dir_path.joinpath("log")
     file_handler = logging.handlers.RotatingFileHandler(
         filename=log_file.as_posix(),
-        mode='a',
+        mode="a",
         maxBytes=file_max_size,
-        backupCount=file_max_number - 1)
+        backupCount=file_max_number - 1,
+    )
     file_handler.setFormatter(
-        logging.Formatter('[%(asctime)s] [%(levelname)s] %(message)s'))
+        logging.Formatter("[%(asctime)s] [%(levelname)s] %(message)s")
+    )
     file_handler.setLevel(logger_level)
     logger.addHandler(file_handler)
 
 
-def add_stream_handler_to_logger(logger: logging.Logger,
-                                 logger_level: int = logging.INFO) -> None:
+def add_stream_handler_to_logger(
+    logger: logging.Logger, logger_level: int = logging.INFO
+) -> None:
     """Add a stream handler to display logging info in console.
 
     :param logger: logger object to which the stream handler should be added.
@@ -142,8 +149,7 @@ def add_stream_handler_to_logger(logger: logging.Logger,
         Messages under the selected level will be ignored by the handler.
     """
     console_handler = logging.StreamHandler()
-    console_handler.setFormatter(
-        logging.Formatter('[%(levelname)s] %(message)s'))
+    console_handler.setFormatter(logging.Formatter("[%(levelname)s] %(message)s"))
     console_handler.setLevel(logger_level)
     logger.addHandler(console_handler)
 
@@ -152,8 +158,9 @@ def get_default_log_dir() -> str:
     """Returns a string with the default location of the directory where log
     files are stored on the host operating system.
     """
-    default_log_dir_by_os: Dict[str, Tuple[str, ...]] = {'Linux': ('.local/var/log/sett',),
-                                                         'Darwin': ('.local/var/log/sett',),
-                                                         'Windows': ('AppData', 'Roaming', 'sett')}
-    return Path.home().joinpath(
-        *default_log_dir_by_os[platform.system()]).as_posix()
+    default_log_dir_by_os: Dict[str, Tuple[str, ...]] = {
+        "Linux": (".local/var/log/sett",),
+        "Darwin": (".local/var/log/sett",),
+        "Windows": ("AppData", "Roaming", "sett"),
+    }
+    return Path.home().joinpath(*default_log_dir_by_os[platform.system()]).as_posix()
